@@ -24,7 +24,6 @@ class APIScorerType(str, Enum):
 
     @classmethod
     def __missing__(cls, value: str) -> APIScorerType:
-        # Handle case-insensitive lookup
         for member in cls:
             if member.value == value.lower():
                 return member
@@ -32,11 +31,6 @@ class APIScorerType(str, Enum):
         raise ValueError(f"Invalid scorer type: {value}")
 
 
-UNBOUNDED_SCORERS: Set[APIScorerType] = (
-    set()
-)  # scorers whose scores are not bounded between 0-1
-
-
 LITELLM_SUPPORTED_MODELS: Set[str] = set(litellm.model_list)
 
 
