@@ -8,8 +8,9 @@ from __future__ import annotations
 
 from pydantic import BaseModel, field_validator
 from typing import List
-from judgeval.constants import UNBOUNDED_SCORERS, APIScorerType
+from judgeval.constants import APIScorerType
 from judgeval.data.example import ExampleParams
+from judgeval.env import JUDGMENT_DEFAULT_GPT_MODEL
 
 
 class APIScorerConfig(BaseModel):
@@ -29,8 +30,8 @@ class APIScorerConfig(BaseModel):
     name: str = ""
     threshold: float = 0.5
     strict_mode: bool = False
+    model: str = JUDGMENT_DEFAULT_GPT_MODEL
 
-    # This is used to check if the example has the required parameters before running the scorer
     required_params: List[ExampleParams] = []
 
     kwargs: dict = {}
@@ -42,16 +43,10 @@ class APIScorerConfig(BaseModel):
         Validates that the threshold is between 0 and 1 inclusive.
         """
         score_type = info.data.get("score_type")
-        if score_type in UNBOUNDED_SCORERS:
-            if v < 0:
-                raise ValueError(
-                    f"Threshold for {score_type} must be greater than 0, got: {v}"
-                )
-        else:
-            if not 0 <= v <= 1:
-                raise ValueError(
-                    f"Threshold for {score_type} must be between 0 and 1, got: {v}"
-                )
+        if not 0 <= v <= 1:
+            raise ValueError(
+                f"Threshold for {score_type} must be between 0 and 1, got: {v}"
+            )
         return v
 
     @field_validator("name", mode="after")
@@ -63,3 +58,11 @@ class APIScorerConfig(BaseModel):
 
     def __str__(self):
         return f"JudgmentScorer(score_type={self.score_type.value}, threshold={self.threshold})"
+
+
+class ExampleAPIScorerConfig(APIScorerConfig):
+    pass
+
+
+class TraceAPIScorerConfig(APIScorerConfig):
+    pass
